@@ -13,7 +13,7 @@ namespace cec {
     using std::make_shared;
 
 #if defined(__cplusplus) && __cplusplus >= 201402L || defined(__cpp_lib_make_unique)
-    using std::make_unique
+    using std::make_unique;
 #else
     template <typename T, typename ...Args>
     std::unique_ptr<T> make_unique(Args&& ...args) {
